@@ -17,9 +17,7 @@
 #include "gdl-i18n.h"
 #include <string.h>
 #include <glib-object.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtktooltips.h>
-#include <gtk/gtkimage.h>
+#include <gtk/gtk.h>
 #include "gdl-dock-item.h"
 #include "gdl-dock-item-grip.h"
 #include "gdl-stock.h"
@@ -35,7 +33,6 @@ enum {
 struct _GdlDockItemGripPrivate {
     GtkWidget   *close_button;
     GtkWidget   *iconify_button;
-    GtkTooltips *tooltips;
 
     gboolean     icon_pixbuf_valid;
     GdkPixbuf   *icon_pixbuf;
@@ -45,7 +42,7 @@ struct _GdlDockItemGripPrivate {
 };
  
 GDL_CLASS_BOILERPLATE (GdlDockItemGrip, gdl_dock_item_grip,
-		       GtkContainer, GTK_TYPE_CONTAINER);
+                       GtkContainer, GTK_TYPE_CONTAINER);
 
 /* must be called after size_allocate */
 static void
@@ -114,7 +111,7 @@ ensure_title_and_icon_pixbuf (GdlDockItemGrip *grip)
 
 static gint
 gdl_dock_item_grip_expose (GtkWidget      *widget,
-			   GdkEventExpose *event)
+                           GdkEventExpose *event)
 {
     GdlDockItemGrip *grip;
     GdkRectangle     title_area;
@@ -153,7 +150,7 @@ gdl_dock_item_grip_expose (GtkWidget      *widget,
                              0, 0, pixbuf_rect.x, pixbuf_rect.y,
                              pixbuf_rect.width, pixbuf_rect.height,
                              GDK_RGB_DITHER_NONE, 0, 0);
-	}
+        }
     }
 
     if (gdk_rectangle_intersect (&title_area, &event->area, &expose_area)) {
@@ -194,20 +191,22 @@ gdl_dock_item_grip_item_notify (GObject    *master,
         ensure_title_and_icon_pixbuf (grip);
 
     } else if (strcmp (pspec->name, "long-name") == 0) {
+        if (grip->_priv->title_layout) {
+                g_object_unref (grip->_priv->title_layout);
+                grip->_priv->title_layout = NULL;
+        }
         g_free (grip->_priv->title);
-        g_object_unref (grip->_priv->title_layout);
-        grip->_priv->title_layout = NULL;
         grip->_priv->title = NULL;
         ensure_title_and_icon_pixbuf (grip);
-	gtk_widget_queue_draw (GTK_WIDGET (grip));
+        gtk_widget_queue_draw (GTK_WIDGET (grip));
     } else if (strcmp (pspec->name, "behavior") == 0) {
-	cursor = FALSE;
+        cursor = FALSE;
         if (grip->_priv->close_button) {
             if (GDL_DOCK_ITEM_CANT_CLOSE (grip->item)) {
                 gtk_widget_hide (GTK_WIDGET (grip->_priv->close_button));
             } else {
                 gtk_widget_show (GTK_WIDGET (grip->_priv->close_button));
-		cursor = TRUE;
+                cursor = TRUE;
             }
         }
         if (grip->_priv->iconify_button) {
@@ -215,10 +214,10 @@ gdl_dock_item_grip_item_notify (GObject    *master,
                 gtk_widget_hide (GTK_WIDGET (grip->_priv->iconify_button));
             } else {
                 gtk_widget_show (GTK_WIDGET (grip->_priv->iconify_button));
-		cursor = TRUE;
+                cursor = TRUE;
             }
         }
-	if (grip->title_window && !cursor)
+        if (grip->title_window && !cursor)
             gdk_window_set_cursor (grip->title_window, NULL);
 
     }
@@ -244,11 +243,6 @@ gdl_dock_item_grip_destroy (GtkObject *object)
             priv->icon_pixbuf = NULL;
         }
 
-        if (priv->tooltips) {
-            g_object_unref (priv->tooltips);
-            priv->tooltips = NULL;
-        }
-
         if (grip->item)
             g_signal_handlers_disconnect_by_func (grip->item,
                                                   gdl_dock_item_grip_item_notify,
@@ -278,15 +272,15 @@ gdl_dock_item_grip_set_property (GObject      *object,
         case PROP_ITEM:
             grip->item = g_value_get_object (value);
             if (grip->item) {
-                g_signal_connect (grip->item, "notify::long_name",
+                g_signal_connect (grip->item, "notify::long-name",
                                   G_CALLBACK (gdl_dock_item_grip_item_notify),
                                   grip);
-                g_signal_connect (grip->item, "notify::stock_id",
+                g_signal_connect (grip->item, "notify::stock-id",
+                                  G_CALLBACK (gdl_dock_item_grip_item_notify),
+                                  grip);
+                g_signal_connect (grip->item, "notify::behavior",
                                   G_CALLBACK (gdl_dock_item_grip_item_notify),
                                   grip);
-		g_signal_connect (grip->item, "notify::behavior",
-		                  G_CALLBACK (gdl_dock_item_grip_item_notify),
-				  grip);
 
                 if (!GDL_DOCK_ITEM_CANT_CLOSE (grip->item) && grip->_priv->close_button)
                     gtk_widget_show (grip->_priv->close_button);
@@ -334,6 +328,7 @@ gdl_dock_item_grip_instance_init (GdlDockItemGrip *grip)
     grip->_priv->icon_pixbuf = NULL;
     grip->_priv->title_layout = NULL;
 
+    /* create the close button */
     gtk_widget_push_composite_child ();
     grip->_priv->close_button = gtk_button_new ();
     gtk_widget_pop_composite_child ();
@@ -350,6 +345,7 @@ gdl_dock_item_grip_instance_init (GdlDockItemGrip *grip)
     g_signal_connect (G_OBJECT (grip->_priv->close_button), "clicked",
                       G_CALLBACK (gdl_dock_item_grip_close_clicked), grip);
 
+    /* create the iconify button */
     gtk_widget_push_composite_child ();
     grip->_priv->iconify_button = gtk_button_new ();
     gtk_widget_pop_composite_child ();
@@ -366,13 +362,11 @@ gdl_dock_item_grip_instance_init (GdlDockItemGrip *grip)
     g_signal_connect (G_OBJECT (grip->_priv->iconify_button), "clicked",
                       G_CALLBACK (gdl_dock_item_grip_iconify_clicked), grip);
 
-    grip->_priv->tooltips = gtk_tooltips_new ();
-    g_object_ref (grip->_priv->tooltips);
-    gtk_object_sink (GTK_OBJECT (grip->_priv->tooltips));
-    gtk_tooltips_set_tip (grip->_priv->tooltips, grip->_priv->iconify_button,
-                          _("Iconify"), _("Iconify this dock"));
-    gtk_tooltips_set_tip (grip->_priv->tooltips, grip->_priv->close_button,
-                          _("Close"), _("Close this dock"));
+    /* set tooltips on the buttons */
+    gtk_widget_set_tooltip_text (grip->_priv->iconify_button,
+                          _("Iconify this dock"));
+    gtk_widget_set_tooltip_text (grip->_priv->close_button,
+                          _("Close this dock"));
 }
 
 static void
@@ -411,14 +405,14 @@ gdl_dock_item_grip_realize (GtkWidget *widget)
         gdk_window_set_user_data (grip->title_window, widget);
  
         if (GDL_DOCK_ITEM_CANT_CLOSE (grip->item))
-	    cursor = NULL;
-	else if (GDL_DOCK_ITEM_CANT_ICONIFY (grip->item))
-	    cursor = NULL;
-	else 
-	    cursor = gdk_cursor_new_for_display (gtk_widget_get_display (widget),
+            cursor = NULL;
+        else if (GDL_DOCK_ITEM_CANT_ICONIFY (grip->item))
+            cursor = NULL;
+        else 
+            cursor = gdk_cursor_new_for_display (gtk_widget_get_display (widget),
                                              GDK_HAND2);
         gdk_window_set_cursor (grip->title_window, cursor);
-	if (cursor)
+        if (cursor)
             gdk_cursor_unref (cursor);
     }
 }
@@ -642,7 +636,7 @@ gdl_dock_item_grip_forall (GtkContainer *container,
     }
 }
 
-static GtkType
+static GType
 gdl_dock_item_grip_child_type (GtkContainer *container)
 {
     return G_TYPE_NONE;
@@ -690,6 +684,15 @@ gdl_dock_item_grip_class_init (GdlDockItemGripClass *klass)
     gdl_stock_init ();
 }
 
+/* ----- Public interface ----- */
+
+/**
+ * gdl_dock_item_grip_new:
+ * @item: The dock item that will "own" this grip widget.
+ * 
+ * Creates a new GDL dock item grip object.
+ * Returns: The newly created dock item grip widget.
+ **/
 GtkWidget *
 gdl_dock_item_grip_new (GdlDockItem *item)
 {
